<?php


namespace Ardent\GrocyApi;


use GuzzleHttp\Client as GuzzleClient;
use GuzzleHttp\RequestOptions;

class Client
{
    private GuzzleClient $client;

    /**
     * Client constructor.
     */
    public function __construct(
        private string $host,
        string         $apikey
    )
    {
        $this->client = new GuzzleClient([
            'base_uri' => $this->getApiUri(),
            'headers' => [
                'GROCY-API-KEY' => $apikey,
            ],
        ]);
    }

    private function getBaseUri(): string
    {
        return $this->host;
    }

    private function getApiUri(): string
    {
        return sprintf('%s/api/',
            self::getBaseUri()
        );
    }

    public function post(string $url, array $data): array
    {
        $data = $this->client->post($url, [
            RequestOptions::JSON => $data,
        ]);

        return json_decode($data->getBody()->getContents(), true);
    }

    public function get(string $url, array $parameters = []): array
    {
        $data = $this->client->get($url, [
            'query' => $parameters,
        ]);

        return json_decode($data->getBody()->getContents(), true);
    }
}